diff src/lib-index/mail-transaction-log.h @ 5849:a9df50952600 HEAD

Added support for resetting index.
author Timo Sirainen <tss@iki.fi>
date Sun, 01 Jul 2007 01:05:26 +0300
parents 4ea31bf18a56
children e4eb71ae8e96
line wrap: on
line diff
--- a/src/lib-index/mail-transaction-log.h	Sun Jul 01 01:04:57 2007 +0300
+++ b/src/lib-index/mail-transaction-log.h	Sun Jul 01 01:05:26 2007 +0300
@@ -146,11 +146,15 @@
 mail_transaction_log_view_open(struct mail_transaction_log *log);
 void mail_transaction_log_view_close(struct mail_transaction_log_view **view);
 
-/* Set view boundaries. Returns -1 if error, 0 if files are lost, 1 if ok. */
-int
-mail_transaction_log_view_set(struct mail_transaction_log_view *view,
-			      uint32_t min_file_seq, uoff_t min_file_offset,
-			      uint32_t max_file_seq, uoff_t max_file_offset);
+/* Set view boundaries. Returns -1 if error, 0 if files are lost, 1 if ok.
+   reset_r=TRUE if the whole index should be reset before applying any
+   changes. */
+int mail_transaction_log_view_set(struct mail_transaction_log_view *view,
+				  uint32_t min_file_seq, uoff_t min_file_offset,
+				  uint32_t max_file_seq, uoff_t max_file_offset,
+				  bool *reset_r);
+/* Clear the view. */
+void mail_transaction_log_view_clear(struct mail_transaction_log_view *view);
 
 /* Read next transaction record from current position. The position is updated.
    Returns -1 if error, 0 if we're at end of the view, 1 if ok. */